import argparse
import logging
import utils
import os

es_client = None


def main(args):
    es_host = args.es_host
    index_name = args.index_name
    region = args.region
    mappings = args.mappings_file
    settings = args.settings_file
    es_username = args.es_username
    es_password = args.es_password

    # Create es client
    logging.info('Creating ES client...')
    global es_client
    es_client = utils.create_es_client(es_host=es_host, region=region,
                                       es_username=es_username, es_password=es_password)

    logging.info('Creating index {}...', index_name)
    create_index(index_name=index_name, mappings_file_path=mappings, settings_file_path=settings)


def create_index(index_name, mappings_file_path, settings_file_path):
    """
    Creates a new index and applies mappings and settings.

    :param index_name:
    :param mappings_file_path:
    :param settings_file_path:
    :return:
    """
    mappings_json = utils.load_json_file(mappings_file_path)
    settings_json = utils.load_json_file(settings_file_path)

    es_schema = {
        'mappings': mappings_json,
        'settings': settings_json
    }

    try:
        es_client.indices.create(index=index_name, body=es_schema)
    except Exception as e:
        logging.error('Failed to create indices. Reason = {}', str(e))
        logging.exception(e)


if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Create a new index.')

    parser.add_argument('-e', '--es-host', dest='es_host', help='Elasticsearch host and port', required=True)
    parser.add_argument('-i', '--index-name', dest='index_name',
                        help='Name of index to be created.', required=True)
    parser.add_argument('-r', '--aws-region', dest='region', default='us-east-1',
                        help='AWS region that the elasticsearch cluster is in. default = us-east-1.')
    parser.add_argument('-m', '--mappings-file', dest='mappings_file', help='Path to elasticsearch mappings file.',
                        required=True)
    parser.add_argument('-u', '--es-username', dest='es_username',
                        help='Username for ES basic auth.', default=os.environ.get('ES_USERNAME', None))
    parser.add_argument('-p', '--es-password', dest='es_password',
                        help='Password for ES basic auth.', default=os.environ.get('ES_PASSWORD', None))
    parser.add_argument('-s', '--settings-file', dest='settings_file', help='Path to elasticsearch settings file.',
                        required=True)

    main(args=parser.parse_args())
